@@ -317,6 +317,15 @@ LIBDE265_API void        de265_push_end_of_NAL(de265_decoder_context* de265ctx)
 }
 
 
+LIBDE265_API void        de265_push_end_of_frame(de265_decoder_context* de265ctx)
+{
+  de265_push_end_of_NAL(de265ctx);
+
+  decoder_context* ctx = (decoder_context*)de265ctx;
+  ctx->nal_parser.mark_end_of_frame();
+}
+
+
 LIBDE265_API de265_error de265_flush_data(de265_decoder_context* de265ctx)
 {
   de265_push_end_of_NAL(de265ctx);
@@ -630,6 +639,11 @@ LIBDE265_API void* de265_get_image_user_data(const struct de265_image* img)
   return img->user_data;
 }
 
+LIBDE265_API void de265_set_image_user_data(struct de265_image* img, void *user_data)
+{
+  img->user_data = user_data;
+}
+
 LIBDE265_API void de265_get_image_NAL_header(const struct de265_image* img,
                                              int* nal_unit_type,
                                              const char** nal_unit_name,
