@@ -496,7 +496,7 @@ de265_error decoder_context::read_vps_NAL(bitreader& reader)
 {
   logdebug(LogHeaders,"---> read VPS\n");
 
-  video_parameter_set vps;
+  video_parameter_set vps = { 0 };
   de265_error err = ::read_vps(this,&reader,&vps);
   if (err != DE265_OK) {
     return err;
@@ -592,6 +592,7 @@ de265_error decoder_context::read_slice_NAL(bitreader& reader, NAL_unit* nal, na
   de265_error err = shdr->read(&reader,this, &continueDecoding);
   if (!continueDecoding) {
     if (img) { img->integrity = INTEGRITY_NOT_DECODED; }
+    nal_parser.free_NAL_unit(nal);
     delete shdr;
     return err;
   }
@@ -604,6 +605,7 @@ de265_error decoder_context::read_slice_NAL(bitreader& reader, NAL_unit* nal, na
   if (process_slice_segment_header(this, shdr, &err, nal->pts, &nal_hdr, nal->user_data) == false)
     {
       img->integrity = INTEGRITY_NOT_DECODED;
+      nal_parser.free_NAL_unit(nal);
       delete shdr;
       return err;
     }
@@ -705,11 +707,21 @@ de265_error decoder_context::decode_some()
 
   if ( ( image_units.size()>=2 && image_units[0]->slice_units.empty() ) ||
        ( image_units.size()>=1 && image_units[0]->slice_units.empty() &&
-         nal_parser.number_of_NAL_units_pending()==0 && nal_parser.is_end_of_stream() )) {
+         nal_parser.number_of_NAL_units_pending()==0 &&
+         (nal_parser.is_end_of_stream() || nal_parser.is_end_of_frame()) )) {
 
     image_unit* imgunit = image_units[0];
 
 
+    // mark all CTBs as decoded even if they are not, because faulty input
+    // streams could miss part of the picture
+    // TODO: this will not work when slice decoding is parallel to post-filtering,
+    // so we will have to replace this with keeping track of which CTB should have
+    // been decoded (but aren't because of the input stream being faulty)
+
+    imgunit->img->mark_all_CTB_progress(CTB_PROGRESS_PREFILTER);
+
+
 
     // run post-processing filters (deblocking & SAO)
 
@@ -1076,6 +1088,10 @@ de265_error decoder_context::decode_NAL(NAL_unit* nal)
       ctx->FirstAfterEndOfSequenceNAL = true;
       nal_parser.free_NAL_unit(nal);
       break;
+
+    default:
+      nal_parser.free_NAL_unit(nal);
+      break;
     }
 
   return err;
@@ -1107,6 +1123,7 @@ de265_error decoder_context::decode(int* more)
   // -> input stalled
 
   if (ctx->nal_parser.is_end_of_stream() == false &&
+      ctx->nal_parser.is_end_of_frame() == false &&
       ctx->nal_parser.get_NAL_queue_length() == 0) {
     if (more) { *more=1; }
 
@@ -1133,6 +1150,12 @@ de265_error decoder_context::decode(int* more)
     err = ctx->decode_NAL(nal);
     // ctx->nal_parser.free_NAL_unit(nal); TODO: do not free NAL with new loop
   }
+  else if (ctx->nal_parser.is_end_of_frame() == true &&
+      ctx->image_units.empty()) {
+    if (more) { *more=1; }
+
+    return DE265_ERROR_WAITING_FOR_INPUT_DATA;
+  }
   else {
     err = decode_some();
   }
@@ -1246,7 +1269,7 @@ int decoder_context::generate_unavailable_reference_picture(decoder_context* ctx
 {
   assert(ctx->dpb.has_free_dpb_picture(true));
 
-  int idx = ctx->dpb.new_image(ctx->current_sps, this);
+  int idx = ctx->dpb.new_image(ctx->current_sps, this, 0,0, false);
   assert(idx>=0);
   //printf("-> fill with unavailable POC %d\n",POC);
 
@@ -1785,7 +1808,7 @@ bool decoder_context::process_slice_segment_header(decoder_context* ctx, slice_s
 
   calc_tid_and_framerate_ratio();
 
-  
+
   // --- prepare decoding of new picture ---
 
   if (hdr->first_slice_segment_in_pic_flag) {
@@ -1803,15 +1826,14 @@ bool decoder_context::process_slice_segment_header(decoder_context* ctx, slice_s
     // --- find and allocate image buffer for decoding ---
 
     int image_buffer_idx;
-    image_buffer_idx = ctx->dpb.new_image(sps, this);
+    bool isOutputImage = (!sps->sample_adaptive_offset_enabled_flag || ctx->param_disable_sao);
+    image_buffer_idx = ctx->dpb.new_image(sps, this, pts, user_data, isOutputImage);
     if (image_buffer_idx == -1) {
       *err = DE265_ERROR_IMAGE_BUFFER_FULL;
       return false;
     }
 
     de265_image* img = ctx->dpb.get_image(image_buffer_idx);
-    img->pts = pts;
-    img->user_data = user_data;
     img->nal_hdr = *nal_hdr;
     ctx->img = img;
 
